@@ -41,8 +41,8 @@ static GtkIconSize icon_size_spec;
 
 typedef struct
 {
-	char        *stock_id;
-	char        *name;
+	const char *stock_id;
+	const char *name;
 	GtkStateType state;
 	gboolean     wildcarded;
 } AppletStockIcon;
@@ -103,7 +103,7 @@ static ModifierStruct modifiers [] = {
 
 typedef struct {
 	unsigned int mask;
-	gchar       *stock_id;
+	const char *stock_id;
 } ButtonIconStruct;
 
 static ButtonIconStruct button_icons [] = {
@@ -120,7 +120,6 @@ about_cb (GSimpleAction *action,
           GVariant      *parameter,
           gpointer       user_data)
 {
-	AccessxStatusApplet *sapplet = (AccessxStatusApplet *) user_data;
         static const gchar *authors [] = {
 		"Calum Benson <calum.benson@sun.com>",
 		"Bill Haneman <bill.haneman@sun.com>",
@@ -354,7 +353,9 @@ timer_reset_slowkeys_image (gpointer user_data)
 	gtk_image_set_from_pixbuf (GTK_IMAGE (user_data), pixbuf); 
 	g_object_unref (pixbuf);
 
-	return FALSE;
+	_sk_timeout = 0;
+
+	return G_SOURCE_REMOVE;
 }
 
 static gboolean
@@ -368,16 +369,18 @@ timer_reset_bouncekeys_image (gpointer user_data)
 	gtk_image_set_from_pixbuf (GTK_IMAGE (user_data), pixbuf); 
 	g_object_unref (pixbuf);
 
-	return FALSE;
+	_bk_timeout = 0;
+
+	return G_SOURCE_REMOVE;
 }
 
 static GdkPixbuf *
-accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet, 
-					GtkWidget *widget,
-					GdkPixbuf *base, 
-					GdkColor  *fg,
-					GdkColor  *bg,
-					gchar *glyphstring)
+accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
+                                        GtkWidget           *widget,
+                                        GdkPixbuf           *base,
+                                        GdkColor            *fg,
+                                        GdkColor            *bg,
+                                        const char          *glyphstring)
 {
 	GdkPixbuf *glyph_pixbuf;
 	cairo_surface_t *surface;
@@ -422,7 +425,7 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 	GdkPixbuf *ret_pixbuf;
 	GdkWindow *window;
 	gboolean is_idle = TRUE;
-	gchar *stock_id = SLOWKEYS_IDLE_ICON;
+	const char *stock_id = SLOWKEYS_IDLE_ICON;
 	GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (sapplet->applet));
 	GdkColor bg = style->bg[GTK_STATE_NORMAL];
 
@@ -462,7 +465,7 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 	if (!is_idle) {
 		GdkPixbuf *glyph_pixbuf, *tmp_pixbuf;
 		GdkColor  fg;
-		gchar * glyphstring = N_("a");
+		const char * glyphstring = N_("a");
 		tmp_pixbuf = ret_pixbuf;
 		ret_pixbuf = gdk_pixbuf_copy (tmp_pixbuf);
 		g_object_unref (tmp_pixbuf);
@@ -502,8 +505,8 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 	GdkColor   fg, bg;
 	GdkPixbuf *icon_base = NULL, *tmp_pixbuf;
 	/* Note to translators: the first letter of the alphabet, not the indefinite article */
-	gchar     *glyphstring = N_("a");
-	gchar *stock_id = ACCESSX_BASE_ICON;
+	const char *glyphstring = N_("a");
+	const char *stock_id = ACCESSX_BASE_ICON;
 
 	g_assert (sapplet->applet);
 	style = gtk_widget_get_style (GTK_WIDGET (sapplet->applet));
@@ -556,7 +559,7 @@ static GdkPixbuf *
 accessx_status_applet_mousekeys_image (AccessxStatusApplet *sapplet, XkbStateNotifyEvent *event)
 {
 	GdkPixbuf  *mouse_pixbuf = NULL, *button_pixbuf, *dot_pixbuf, *tmp_pixbuf;
-	gchar *which_dot = MOUSEKEYS_DOT_LEFT;
+	const char *which_dot = MOUSEKEYS_DOT_LEFT;
 	tmp_pixbuf = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
 					       MOUSEKEYS_BASE_ICON,
 					       icon_size_spec, 
@@ -891,7 +894,7 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 	gtk_icon_factory_add_default (factory);
        
         while (i <  G_N_ELEMENTS (stock_icons)) {
-		gchar *set_name = stock_icons[i].stock_id;
+		const char *set_name = stock_icons[i].stock_id;
                 icon_set = gtk_icon_set_new ();
 		do {
 			char *filename;
@@ -932,60 +935,6 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 	sapplet->icon_factory = factory;
 }
 
-static void
-accessx_status_applet_reparent_widget (GtkWidget *widget, GtkContainer *container) 
-{
-	if (widget) {
-		if (gtk_widget_get_parent (widget)) {
-			g_object_ref (G_OBJECT (widget));
-			gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (widget)), widget);
-		}
-		gtk_container_add (container, widget);
-	}
-}
-
-static void
-accessx_status_applet_layout_box (AccessxStatusApplet *sapplet, GtkWidget *box, GtkWidget *stickyfoo) 
-{
-        AtkObject *atko;
-
-	accessx_status_applet_reparent_widget (sapplet->shift_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->ctrl_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->alt_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->meta_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->hyper_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->super_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->alt_graph_indicator, GTK_CONTAINER (stickyfoo));
-	accessx_status_applet_reparent_widget (sapplet->idlefoo, GTK_CONTAINER (box));
-	accessx_status_applet_reparent_widget (sapplet->mousefoo, GTK_CONTAINER (box));
-	accessx_status_applet_reparent_widget (stickyfoo, GTK_CONTAINER (box));
-	accessx_status_applet_reparent_widget (sapplet->slowfoo, GTK_CONTAINER (box));
-	accessx_status_applet_reparent_widget (sapplet->bouncefoo, GTK_CONTAINER (box));
-
-	if (sapplet->stickyfoo) {
-		gtk_widget_destroy (sapplet->stickyfoo); 
-	}
-
-	if (sapplet->box) {
-		gtk_container_remove (GTK_CONTAINER (sapplet->applet), sapplet->box);
-	}
-
-	gtk_container_add (GTK_CONTAINER (sapplet->applet), box);
-	sapplet->stickyfoo = stickyfoo;
-	sapplet->box = box;
-
-	atko = gtk_widget_get_accessible (sapplet->box);
-	atk_object_set_name (atko, _("AccessX Status"));
-	atk_object_set_description (atko, _("Shows keyboard status when accessibility features are used."));
-
-	gtk_widget_show (sapplet->box);
-	gtk_widget_show (GTK_WIDGET (sapplet->applet));
-
-	if (gtk_widget_get_realized (sapplet->box) &&
-            sapplet->initialized)
-		accessx_status_applet_update (sapplet, ACCESSX_STATUS_ALL, NULL);
-}
-
 static void 
 disable_applet (AccessxStatusApplet* sapplet)
 {
@@ -1044,13 +993,11 @@ static AccessxStatusApplet *
 create_applet (PanelApplet *applet)
 {
 	AccessxStatusApplet *sapplet = g_new0 (AccessxStatusApplet, 1);
-	GtkWidget           *box, *stickyfoo;
 	AtkObject           *atko;
 	GdkPixbuf	    *pixbuf;
 
 	sapplet->xkb = NULL;
 	sapplet->xkb_display = NULL;
-	sapplet->box = NULL;
 	sapplet->initialized = False; /* there must be a better way */
 	sapplet->error_type = ACCESSX_STATUS_ERROR_NONE;
 	sapplet->applet = applet;
@@ -1058,19 +1005,18 @@ create_applet (PanelApplet *applet)
 	sapplet->orient = panel_applet_get_orient (applet);
 	if (sapplet->orient == PANEL_APPLET_ORIENT_LEFT || 
 	    sapplet->orient == PANEL_APPLET_ORIENT_RIGHT) {
-		box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		stickyfoo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		sapplet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		sapplet->stickyfoo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	}
 	else {
-		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		stickyfoo = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		sapplet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		sapplet->stickyfoo = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	}
-	gtk_box_set_homogeneous (GTK_BOX (stickyfoo), TRUE);
 
 	sapplet->size = 24;
 	icon_size_spec = GTK_ICON_SIZE_LARGE_TOOLBAR;       
 
-	accessx_applet_add_stock_icons (sapplet, box);
+	accessx_applet_add_stock_icons (sapplet, sapplet->box);
 	pixbuf = accessx_status_applet_mousekeys_image (sapplet, NULL);
 	sapplet->mousefoo = gtk_image_new_from_pixbuf (pixbuf);
 	g_object_unref (pixbuf);
@@ -1112,10 +1058,39 @@ create_applet (PanelApplet *applet)
 	sapplet->idlefoo = gtk_image_new_from_stock (ACCESSX_APPLET, icon_size_spec);
 	gtk_widget_show (sapplet->slowfoo);
 
-	accessx_status_applet_layout_box (sapplet, box, stickyfoo);
+	gtk_container_add (GTK_CONTAINER (sapplet->applet), sapplet->box);
+	gtk_widget_show (sapplet->box);
+
+	gtk_container_add (GTK_CONTAINER (sapplet->box), sapplet->idlefoo);
+	gtk_container_add (GTK_CONTAINER (sapplet->box), sapplet->mousefoo);
+	gtk_container_add (GTK_CONTAINER (sapplet->box), sapplet->stickyfoo);
+	gtk_container_add (GTK_CONTAINER (sapplet->box), sapplet->slowfoo);
+	gtk_container_add (GTK_CONTAINER (sapplet->box), sapplet->bouncefoo);
+
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->shift_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->ctrl_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->alt_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->meta_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->hyper_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->super_indicator);
+	gtk_container_add (GTK_CONTAINER (sapplet->stickyfoo), sapplet->alt_graph_indicator);
+
+	gtk_box_set_homogeneous (GTK_BOX (sapplet->stickyfoo), TRUE);
+	gtk_widget_show (sapplet->stickyfoo);
+
+	gtk_widget_show (GTK_WIDGET (sapplet->applet));
+
+	if (gtk_widget_get_realized (sapplet->box) && sapplet->initialized)
+		accessx_status_applet_update (sapplet, ACCESSX_STATUS_ALL, NULL);
+
 	atko = gtk_widget_get_accessible (GTK_WIDGET (sapplet->applet));
 	atk_object_set_name (atko, _("AccessX Status"));
 	atk_object_set_description (atko, _("Shows keyboard status when accessibility features are used."));
+
+	atko = gtk_widget_get_accessible (sapplet->box);
+	atk_object_set_name (atko, _("AccessX Status"));
+	atk_object_set_description (atko, _("Shows keyboard status when accessibility features are used."));
+
 	return sapplet;
 }
 
@@ -1137,21 +1112,25 @@ static void
 accessx_status_applet_reorient (GtkWidget *widget, PanelAppletOrient o, gpointer user_data)
 {
 	AccessxStatusApplet *sapplet = user_data;
-	GtkWidget           *box, *stickyfoo;
 
 	sapplet->orient = o;
 
 	if (o == PANEL_APPLET_ORIENT_LEFT || 
 	    o == PANEL_APPLET_ORIENT_RIGHT) {
-		box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		stickyfoo = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+		gtk_orientable_set_orientation (GTK_ORIENTABLE (sapplet->box),
+		                                GTK_ORIENTATION_VERTICAL);
+		gtk_orientable_set_orientation (GTK_ORIENTABLE (sapplet->stickyfoo),
+		                                GTK_ORIENTATION_VERTICAL);
 	}
 	else {
-		box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		stickyfoo = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		gtk_orientable_set_orientation (GTK_ORIENTABLE (sapplet->box),
+		                                                GTK_ORIENTATION_HORIZONTAL);
+		gtk_orientable_set_orientation (GTK_ORIENTABLE (sapplet->stickyfoo),
+		                                                GTK_ORIENTATION_HORIZONTAL);
 	}
-	gtk_box_set_homogeneous (GTK_BOX (stickyfoo), TRUE);
-	accessx_status_applet_layout_box (sapplet, box, stickyfoo);
+
+	if (gtk_widget_get_realized (sapplet->box) && sapplet->initialized)
+		accessx_status_applet_update (sapplet, ACCESSX_STATUS_ALL, NULL);
 }
 
 static void
