@@ -166,11 +166,11 @@ toggle_button_toggled_cb(GtkToggleButton *button, gpointer data)
     unichar = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "unichar"));
     curr_data->selected_unichar = unichar;
     /* set this? widget as the selection owner */
-    gtk_selection_owner_set (curr_data->applet,
-	  		     GDK_SELECTION_PRIMARY,
+    gtk_selection_owner_set (curr_data->invisible,
+                             GDK_SELECTION_PRIMARY,
                              GDK_CURRENT_TIME); 
-    gtk_selection_owner_set (curr_data->applet,
-	  		     GDK_SELECTION_CLIPBOARD,
+    gtk_selection_owner_set (curr_data->invisible,
+                             GDK_SELECTION_CLIPBOARD,
                              GDK_CURRENT_TIME); 
   }	
 	     
@@ -491,6 +491,29 @@ build_table(charpick_data *p_curr_data)
   p_curr_data->last_toggle_button = NULL;
 }
 
+static gboolean
+rebuild_cb (gpointer user_data)
+{
+  charpick_data *curr_data;
+
+  curr_data = user_data;
+  curr_data->rebuild_id = 0;
+
+  build_table (curr_data);
+
+  return G_SOURCE_REMOVE;
+}
+
+static void
+queue_rebuild (charpick_data *curr_data)
+{
+  if (curr_data->rebuild_id != 0)
+    return;
+
+  curr_data->rebuild_id = g_idle_add (rebuild_cb, curr_data);
+  g_source_set_name_by_id (curr_data->rebuild_id, "[charpick] rebuild_cb");
+}
+
 static void applet_size_allocate(PanelApplet *applet, GtkAllocation *allocation, gpointer data)
 {
   charpick_data *curr_data = data;
@@ -504,7 +527,7 @@ static void applet_size_allocate(PanelApplet *applet, GtkAllocation *allocation,
     curr_data->panel_size = allocation->height;
   }
 
-  build_table (curr_data);
+  queue_rebuild (curr_data);
   return;
 }
 
@@ -579,7 +602,13 @@ applet_destroy (GtkWidget *widget, gpointer data)
   charpick_data *curr_data = data;
 
   g_return_if_fail (curr_data);
-   
+
+  if (curr_data->rebuild_id != 0)
+    {
+      g_source_remove (curr_data->rebuild_id);
+      curr_data->rebuild_id = 0;
+    }
+
   if (curr_data->about_dialog)
     gtk_widget_destroy (curr_data->about_dialog);   
   if (curr_data->propwindow)
@@ -590,8 +619,9 @@ applet_destroy (GtkWidget *widget, gpointer data)
     gtk_widget_destroy (curr_data->menu);
   if (curr_data->settings)
     g_object_unref (curr_data->settings);
+  if (curr_data->invisible)
+    gtk_widget_destroy (curr_data->invisible);
   g_free (curr_data);
-  
 }
 
 void 
@@ -667,6 +697,7 @@ charpicker_applet_fill (PanelApplet *applet)
 {
   PanelAppletOrient orientation;
   charpick_data *curr_data;
+  GdkScreen *screen;
   GdkAtom utf8_atom;
   GList *list;
   gchar *string;
@@ -681,7 +712,8 @@ charpicker_applet_fill (PanelApplet *applet)
   curr_data->about_dialog = NULL;
   curr_data->add_edit_dialog = NULL;
   curr_data->settings = panel_applet_settings_new (applet, CHARPICK_SCHEMA);
- 
+  curr_data->rebuild_id = 0;
+
   get_chartable (curr_data);
   
   string = g_settings_get_string (curr_data->settings, KEY_CURRENT_LIST);
@@ -711,22 +743,27 @@ charpicker_applet_fill (PanelApplet *applet)
   g_signal_connect (G_OBJECT (curr_data->applet), "key_press_event",
 		             G_CALLBACK (key_press_event), curr_data);
 
+  screen = gtk_widget_get_screen (GTK_WIDGET (applet));
+  curr_data->invisible = gtk_invisible_new_for_screen (screen);
+
   utf8_atom = gdk_atom_intern ("UTF8_STRING", FALSE);
-  gtk_selection_add_target (curr_data->applet, 
-			    GDK_SELECTION_PRIMARY,
+  gtk_selection_add_target (curr_data->invisible,
+                            GDK_SELECTION_PRIMARY,
                             utf8_atom,
-			    0);
-  gtk_selection_add_target (curr_data->applet, 
-			    GDK_SELECTION_CLIPBOARD,
+                            0);
+  gtk_selection_add_target (curr_data->invisible,
+                            GDK_SELECTION_CLIPBOARD,
                             utf8_atom,
-			    0);
-  g_signal_connect (G_OBJECT (curr_data->applet), "selection_get",
-		      G_CALLBACK (charpick_selection_handler),
-		      curr_data);
-  g_signal_connect (G_OBJECT (curr_data->applet), "selection_clear_event",
-		      G_CALLBACK (selection_clear_cb),
-		      curr_data);
- 
+                            0);
+  g_signal_connect (curr_data->invisible,
+                    "selection_get",
+                    G_CALLBACK (charpick_selection_handler),
+                    curr_data);
+  g_signal_connect (curr_data->invisible,
+                    "selection_clear_event",
+                    G_CALLBACK (selection_clear_cb),
+                    curr_data);
+
   make_applet_accessible (GTK_WIDGET (applet));
 
   /* session save signal */ 
