@@ -128,16 +128,6 @@ G_DEFINE_TYPE (NetspeedApplet, netspeed_applet, PANEL_TYPE_APPLET)
 static void
 update_tooltip(NetspeedApplet* applet);
 
-/* Adds a Pango markup "size" to a bytestring
- */
-static void
-add_markup_size(char **string, int size)
-{
-	char *tmp = *string;
-	*string = g_strdup_printf("<span size=\"%d\">%s</span>", size * 1000, tmp);
-	g_free(tmp);
-}
-
 /* Adds a Pango markup "foreground" to a bytestring
  */
 static void
@@ -275,9 +265,6 @@ change_icons(NetspeedApplet *applet)
 	in_arrow = gtk_icon_theme_load_icon(icon_theme, IN_ICON, 16, 0, NULL);
 	out_arrow = gtk_icon_theme_load_icon(icon_theme, OUT_ICON, 16, 0, NULL);
 
-	/* Set the windowmanager icon for the applet */
-	gtk_window_set_default_icon_name(LOGO_ICON);
-
 	gtk_image_set_from_pixbuf(GTK_IMAGE(applet->out_pix), out_arrow);
 	gtk_image_set_from_pixbuf(GTK_IMAGE(applet->in_pix), in_arrow);
 	g_object_unref(in_arrow);
@@ -642,33 +629,6 @@ about_cb (GSimpleAction *action,
 	
 }
 
-/* Called when the showsum checkbutton is toggled...
- */
-static void
-showsum_change_cb(GtkToggleButton *togglebutton, NetspeedApplet *applet)
-{
-	applet->show_sum = gtk_toggle_button_get_active(togglebutton);
-	applet_change_size_or_orient (PANEL_APPLET (applet), -1, applet);
-	change_icons(applet);
-}
-
-/* Called when the showbits checkbutton is toggled...
- */
-static void
-showbits_change_cb(GtkToggleButton *togglebutton, NetspeedApplet *applet)
-{
-	applet->show_bits = gtk_toggle_button_get_active(togglebutton);
-}
-
-/* Called when the changeicon checkbutton is toggled...
- */
-static void
-changeicon_change_cb(GtkToggleButton *togglebutton, NetspeedApplet *applet)
-{
-	applet->change_icon = gtk_toggle_button_get_active(togglebutton);
-	change_icons(applet);
-}
-
 static void
 netspeed_applet_destory_preferences (GtkWidget *widget,
                                      gpointer   user_data)
@@ -1454,7 +1414,6 @@ netspeed_applet_factory (PanelApplet *applet,
 	netspeed = NETSPEED_APPLET (applet);
 
 	glibtop_init();
-	g_set_application_name (_("Netspeed"));
 
 	/* Alloc the applet. The "NULL-setting" is really redudant
  	 * but aren't we paranoid?
@@ -1478,6 +1437,10 @@ netspeed_applet_factory (PanelApplet *applet,
 	netspeed->out_label = netspeed_label_new ();
 	netspeed->sum_label = netspeed_label_new ();
 
+	panel_applet_add_text_class (applet, netspeed->in_label);
+	panel_applet_add_text_class (applet, netspeed->out_label);
+	panel_applet_add_text_class (applet, netspeed->sum_label);
+
 	netspeed->in_pix = gtk_image_new ();
 	netspeed->out_pix = gtk_image_new ();
 	netspeed->dev_pix = gtk_image_new ();
@@ -1594,7 +1557,7 @@ netspeed_applet_get_auto_device_name (void)
 	return g_strdup ("lo");
 }
 
-PANEL_APPLET_OUT_PROCESS_FACTORY ("NetspeedAppletFactory",
-                                  NETSPEED_TYPE_APPLET,
-                                  netspeed_applet_factory,
-                                  NULL)
+PANEL_APPLET_IN_PROCESS_FACTORY ("NetspeedAppletFactory",
+                                 NETSPEED_TYPE_APPLET,
+                                 netspeed_applet_factory,
+                                 NULL)
